@@ -38,7 +38,7 @@ compute.aggte <- function(MP,
 
 
   gname <- dp$gname
-  data <- dp$data
+  data <- as.data.frame(dp$data)
   tname <- dp$tname
   idname <- dp$idname
   if(is.null(clustervars)){
@@ -69,6 +69,9 @@ compute.aggte <- function(MP,
   MP$DIDparams$cband <- cband
   dp <- MP$DIDparams
 
+  if(!(type %in% c("simple", "dynamic", "group", "calendar"))) {
+    stop('`type` must be one of c("simple", "dynamic", "group", "calendar")')
+  }
 
   if(na.rm){
     notna <- !is.na(att)
@@ -127,15 +130,17 @@ compute.aggte <- function(MP,
   originalgroup <- group
   originalglist <- glist
   originaltlist <- tlist
-  uniquet <- seq(1,length(unique(t)))
+  # In case g's are not part of tlist
+  originalgtlist <- sort(unique(c(originaltlist,originalglist)))
+  uniquet <- seq(1,length(unique(originalgtlist)))
   # function to switch from "new" t values to  original t values
   t2orig <- function(t) {
-    unique(c(originalt,0))[which(c(uniquet,0)==t)]
+    unique(c(originalgtlist,0))[which(c(uniquet,0)==t)]
   }
   # function to switch between "original"
   #  t values and new t values
   orig2t <- function(orig) {
-    new_t <- c(uniquet,0)[which(unique(c(originalt,0))==orig)]
+    new_t <- c(uniquet,0)[which(unique(c(originalgtlist,0))==orig)]
     out <- ifelse(length(new_t) == 0, NA, new_t)
     out
   }
@@ -329,8 +334,13 @@ compute.aggte <- function(MP,
 
     # if we balance the sample with resepect to event time
     if (!is.null(balance_e)) {
-      eseq <- eseq[ (eseq <= balance_e) & (eseq >= balance_e - t2orig(maxT) + t2orig(1))]
       include.balanced.gt <- (t2orig(maxT) - originalgroup >= balance_e)
+
+      eseq <- unique(originalt[include.balanced.gt] - originalgroup[include.balanced.gt])
+      eseq <- eseq[order(eseq)]
+
+      eseq <- eseq[ (eseq <= balance_e) & (eseq >= balance_e - t2orig(maxT) + t2orig(1))]
+
     }
 
     # only looks at some event times
@@ -558,7 +568,7 @@ wif <- function(keepers, pg, weights.ind, G, group) {
       sum(pg[keepers])
   })
   # effect of estimating weights in the denominator
-  if2 <- rowSums( sapply( keepers, function(k) {
+  if2 <- base::rowSums( sapply( keepers, function(k) {
     weights.ind*1*BMisc::TorF(G==group[k]) - pg[k]
   })) %*%
     t(pg[keepers]/(sum(pg[keepers])^2))
